@@ -13,7 +13,7 @@ use Perinci::Sub::Util qw(gen_modified_sub);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-16'; # DATE
 our $DIST = 'App-DownloadsDirUtils'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our %SPEC;
 
@@ -84,7 +84,7 @@ MARKDOWN
         summary => "Move the $which file(s) from the downloads directories to current directory",
         description => <<"MARKDOWN",
 
-This is a thin wrapper for the <prog:${which}_download> utility; the wrapper
+This is a thin wrapper for the <prog:${which}-download> utility; the wrapper
 moves the files to current directory. It hopes to be a convenient helper to
 organize your downloads.
 
@@ -153,7 +153,7 @@ App::DownloadsDirUtils - Utilities related to downloads directories
 
 =head1 VERSION
 
-This document describes version 0.003 of App::DownloadsDirUtils (from Perl distribution App-DownloadsDirUtils), released on 2023-11-16.
+This document describes version 0.004 of App::DownloadsDirUtils (from Perl distribution App-DownloadsDirUtils), released on 2023-11-16.
 
 =head1 DESCRIPTION
 
@@ -455,7 +455,7 @@ Usage:
 
 Move the foremost file(s) from the downloads directories to current directory.
 
-This is a thin wrapper for the L<foremost_download> utility; the wrapper
+This is a thin wrapper for the L<foremost-download> utility; the wrapper
 moves the files to current directory. It hopes to be a convenient helper to
 organize your downloads.
 
@@ -553,7 +553,7 @@ Usage:
 
 Move the hindmost file(s) from the downloads directories to current directory.
 
-This is a thin wrapper for the L<hindmost_download> utility; the wrapper
+This is a thin wrapper for the L<hindmost-download> utility; the wrapper
 moves the files to current directory. It hopes to be a convenient helper to
 organize your downloads.
 
@@ -651,7 +651,7 @@ Usage:
 
 Move the largest file(s) from the downloads directories to current directory.
 
-This is a thin wrapper for the L<largest_download> utility; the wrapper
+This is a thin wrapper for the L<largest-download> utility; the wrapper
 moves the files to current directory. It hopes to be a convenient helper to
 organize your downloads.
 
@@ -745,7 +745,7 @@ Usage:
 
 Move the newest file(s) from the downloads directories to current directory.
 
-This is a thin wrapper for the L<newest_download> utility; the wrapper
+This is a thin wrapper for the L<newest-download> utility; the wrapper
 moves the files to current directory. It hopes to be a convenient helper to
 organize your downloads.
 
@@ -839,7 +839,7 @@ Usage:
 
 Move the oldest file(s) from the downloads directories to current directory.
 
-This is a thin wrapper for the L<oldest_download> utility; the wrapper
+This is a thin wrapper for the L<oldest-download> utility; the wrapper
 moves the files to current directory. It hopes to be a convenient helper to
 organize your downloads.
 
@@ -933,7 +933,7 @@ Usage:
 
 Move the smallest file(s) from the downloads directories to current directory.
 
-This is a thin wrapper for the L<smallest_download> utility; the wrapper
+This is a thin wrapper for the L<smallest-download> utility; the wrapper
 moves the files to current directory. It hopes to be a convenient helper to
 organize your downloads.
 
